# pip install anitejb

## Table of Contents
- [Overview](#overview)
- [Usage](#usage)
- [License](#license)
- [Contributions](#contributions)
    - [Approved List of Contributors](#approved-list-of-contributors)

## Overview
A collection of custom [Python](https://www.python.org/) tools and functions developed for me, by me, with <3.

Full disclosure: the functionality provided in this package may exist in various other forms across the depths of the internet. Everything here stems from a personal experience when I needed Python features that were not in-built/importable. I thought would be nice to have all of these things in one place, so here it is.

## Usage
The package is live on [PyPI](https://pypi.org/project/anitejb). I plan to use it, and you could too! All you need are three magic words: `pip install anitejb`

That being said, keep in mind that this package was developed solely for my own use, and quite literally everything could change at any moment with zero prior notice.

Unless (and even if) you are me, I would not recommend using this on large scale and/or somewhat important projects. You wouldn't want [this](https://xkcd.com/2347/) to happen.

## License
Copyright (c) 2021 Anitej Biradar. Released under the MIT License. See
[LICENSE](LICENSE) for details.

## Contributions
Due to the custom nature of this project, in order to contribute `code`, you must be on the **approved list of contributors** (shown below).

Things that don't require approval: questions, comments, concerns, thoughts, opinions, and cute animal pictures — reach out to [pip@anitejb.dev](mailto:pip@anitejb.dev)!

### Approved List of Contributors
- [Anitej Biradar](https://github.com/anitejb)

Requests to be added to this list will only be considered on the 20th of April every 48 years.

The 2021 cycle has concluded. Details regarding the next cycle will be published closer to the event.
